use crate::{
    install::{str_vec, uncomment_tag},
    is_root, run_command,
};

pub fn create_iso(without_gui: bool) {
    if !is_root() {
        eprintln!("Error: You need root to create an ISO");
        std::process::exit(1);
    }

    if !std::fs::exists("./iso").unwrap() {
        let cmd = str_vec(vec!["git", "clone", "https://git.hydrar.de/navos/iso"]);
        run_command(&cmd, None, false);
    }

    if without_gui {
        std::fs::remove_file("./iso/airootfs/etc/systemd/system/display-manager.service").unwrap();
    } else {
        println!("Adding GUI packages");
        uncomment_tag("#gui: ", "./iso/packages.x86_64");
    }

    std::fs::create_dir_all("./work").unwrap();

    let mount_cmd = str_vec(vec![
        "mount", "-t", "tmpfs", "-o", "size=10G", "tmpfs", "./work",
    ]);

    run_command(&mount_cmd, None, false);

    let mkarchiso_cmd = vec![
        "mkarchiso".to_string(),
        "-v".to_string(),
        "-w".to_string(),
        "./work".to_string(),
        "-o".to_string(),
        "./".to_string(),
        "./iso".to_string(),
    ];

    run_command(&mkarchiso_cmd, None, true);

    let umount_cmd = str_vec(vec!["umount", "-r", "./work"]);

    run_command(&umount_cmd, None, false);

    std::fs::remove_dir_all("./work").unwrap();
}
